AppConsoleLogEntry class
Console 日志的单条记录。
Constructors
-
AppConsoleLogEntry({required DateTime at, required AppLogLevel level, required String message, String? tag, Map<
String, Object?> ? extra}) -
const
Properties
- at → DateTime
-
final
-
extra
→ Map<
String, Object?> ? -
附加的结构化数据,展示为 JSON 块。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → AppLogLevel
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited